@@ -5,6 +5,7 @@ from sqlalchemy import (
     Integer,
     DateTime,
     ForeignKey,
+    Boolean,
 )
 
 from ...database import Base
@@ -29,6 +30,10 @@ class CompanyLicensingCollabOutboxModel(Base):
         ForeignKey('companies_ous.id'),
         nullable=True,
     )
+    target_flag = Column(
+        Boolean,
+        nullable=True,
+    )
     updated_at = Column(
         DateTime,
         nullable=False,
