@@ -4,6 +4,7 @@ from sqlalchemy import (
     String,
     DateTime,
     ForeignKey,
+    Boolean,
 )
 from datetime import datetime
 
@@ -34,6 +35,7 @@ class CompanyOutboxModel(Base):
         ForeignKey('newswires.id'),
         nullable=True,
     )
+    historical = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
