@@ -5,6 +5,7 @@ from sqlalchemy import (
     DateTime,
     UniqueConstraint,
     Boolean,
+    Text,
 )
 from datetime import datetime
 
@@ -15,6 +16,7 @@ class CompanySECModel(Base):
     __tablename__ = 'companies_sec'
 
     id = Column(Integer, primary_key=True)
+    lead = Column(Boolean, nullable=True)
     cik_str = Column(String(128), nullable=False)
     ticker = Column(String(20), nullable=False, index=True)
     title = Column(String(255), nullable=False, index=True)
@@ -24,10 +26,13 @@ class CompanySECModel(Base):
     ir_url = Column(String(255), nullable=True)
     is_activated = Column(Boolean, nullable=True)
     is_biopharma = Column(Boolean, nullable=True)
+    is_searchable = Column(Boolean, nullable=True)
     discarded = Column(Boolean, nullable=True)
     skip_sec = Column(Boolean, nullable=True)
     last_crawl_date = Column(DateTime, nullable=True)
     industry_type = Column(String(50), nullable=True)
+    relevant_links = Column(Text, nullable=True)
+    notes = Column(Text, nullable=True)
     updated_at = Column(
         DateTime,
         default=datetime.utcnow,
