@@ -10,6 +10,8 @@ class DrugIndicationResourceSchema(Schema):
 
     id = fields.Integer(dump_only=True)
     set_id = fields.String(validate=not_blank, required=True)
+    doc_id = fields.String(validate=not_blank, required=True)
+    version = fields.String(required=True)
     lowercase_indication = fields.String(allow_none=True)
     indication = fields.String(allow_none=True)
     label_file_id = fields.Integer(allow_none=True)
@@ -21,6 +23,7 @@ class DrugIndicationQueryParamsSchema(Schema):
 
     id = fields.Integer()
     set_id = fields.String(validate=not_blank)
+    doc_id = fields.String(validate=not_blank)
     lowercase_indication = fields.String(allow_none=True)
     indication = fields.String(allow_none=True)
     label_file_id = fields.Integer(allow_none=True)
@@ -30,6 +33,7 @@ class DrugIndicationPatchSchema(Schema):
     not_blank = validate.Length(min=1, error='Field cannot be blank')
 
     set_id = fields.String(validate=not_blank)
+    doc_id = fields.String(validate=not_blank)
     lowercase_indication = fields.String(allow_none=True)
     indication = fields.String(allow_none=True)
     label_file_id = fields.Integer(allow_none=True)
