@@ -12,4 +12,8 @@ class InsightsQueueResourceSchema(Schema):
     source_type = fields.String(required=True)
     source_id = fields.Integer(required=True)
     processed = fields.Boolean(allow_none=True)
+    error = fields.String(allow_none=True)
+    submitted = fields.Boolean(allow_none=True)
+    submitted_date = fields.DateTime(allow_none=True)
+    historical = fields.Boolean(allow_none=True)
     updated_at = fields.DateTime(dump_only=True)
