@@ -19,9 +19,10 @@ class NCTChangeModel(Base):
         Integer,
         ForeignKey('nct_study.id'),
         nullable=True,
+        index=True,
     )
-    date = Column(DateTime, nullable=False)
-    change_type = Column(String(50), nullable=False)
+    date = Column(DateTime, nullable=False, index=True)
+    change_type = Column(String(50), nullable=False, index=True)
     news_id = Column(
         Integer,
         ForeignKey('newswires.id'),
