@@ -20,7 +20,7 @@ class NCTDesignOutcomesResourceSchema(Schema):
     updated_at = fields.DateTime(dump_only=True)
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = ['last_update_submitted_qc_date']
 
         in_data = pre_load_date_fields(
