@@ -2,6 +2,7 @@ from sqlalchemy import (
     Column,
     Integer,
     DateTime,
+    Boolean,
 )
 from datetime import datetime
 
@@ -17,6 +18,8 @@ class NewswireClinicalTrialOutboxModel(Base):
         nullable=False,
         index=True,
     )
+    submitted = Column(Boolean, nullable=True)
+    historical = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
