@@ -10,4 +10,6 @@ class NewswireCompanyUpdateOutboxResourceSchema(Schema):
 
     id = fields.Integer(dump_only=True)
     news_id = fields.Integer(required=True)
+    submitted = fields.Boolean(allow_none=True)
+    historical = fields.Boolean(allow_none=True)
     updated_at = fields.DateTime()
