@@ -30,6 +30,8 @@ class NotificationModel(Base):
     source_detail = Column(Text, nullable=False)
     seen_at = Column(DateTime, nullable=True)
     processed_at = Column(DateTime, nullable=True)
+    daily_processed_at = Column(DateTime, nullable=True)
+    weekly_processed_at = Column(DateTime, nullable=True)
     date = Column(DateTime, nullable=False)
     updated_at = Column(
         DateTime,
