@@ -19,5 +19,7 @@ class NotificationResourceSchema(Schema):
     source_detail = fields.String(required=True)
     seen_at = fields.DateTime(allow_none=True)
     processed_at = fields.DateTime(allow_none=True)
+    daily_processed_at = fields.DateTime(allow_none=True)
+    weekly_processed_at = fields.DateTime(allow_none=True)
     date = fields.DateTime(required=True)
     updated_at = fields.DateTime()
