@@ -43,6 +43,8 @@ class PatentResourceSchema(Schema):
     assignee = fields.String(allow_none=True)
     patent_pdf_url = fields.String(allow_none=True)
     espace_url = fields.String(allow_none=True)
+    docdb_family_id = fields.Integer(allow_none=True)
+    inpadoc_family_id = fields.Integer(allow_none=True)
 
     updated_at = fields.DateTime()
 
