@@ -12,5 +12,5 @@ class PatentApplicationSubsidiaryResourceSchema(Schema):
     patent_application_id = fields.Integer(required=True)
     subsidiary_id = fields.Integer(required=True)
     score = fields.Float(required=True)
-    filed_date = fields.DateTime(allow_none=True)
+    published_date = fields.DateTime(allow_none=True)
     updated_at = fields.DateTime()
