@@ -15,9 +15,10 @@ class PriorArtRefRelationResourceSchema(Schema):
     updated_at = fields.DateTime(dump_only=True)
 
     @pre_load
-    def pre_load(self, in_data, **kwargs):
+    def check_ref_fields(self, in_data, **kwargs):
         if self._get_number_of_ref_fields(in_data) != 1:
             raise ValidationError('Provide only one of the ref fields')
+        return in_data
 
     def _get_number_of_ref_fields(self, in_data, **kwargs):
         result = 0
