@@ -13,4 +13,7 @@ class UserSavedSearchResourceSchema(Schema):
     is_deleted = fields.Boolean(allow_none=True)
     created_at = fields.DateTime(required=True)
     last_processed = fields.DateTime(allow_none=True)
+    instant_notification = fields.Boolean(allow_none=True)
+    daily_digest = fields.Boolean(allow_none=True)
+    weekly_digest = fields.Boolean(allow_none=True)
     updated_at = fields.DateTime(dump_only=True)
